function [x,t] = RungeKutta_Order4_Coupled(MyFunc,InitialValues,Start,Finish,Nsteps)
% solves an initial value problem which consists of several coupled ODE's, each of the form
% dxi/dt = fi(x,t)
% Uses a 4th order Runge-Kutta method
%
% INPUTS 
% ------
% Myfunc       = Handle to the function which calculates F(x,t)
% InitialValue = starting value
% Start        = start time
% finish       = end time 
% Nsteps       = number of steps to march forward
%
% OUTPUTS
% -------
% x            = an array containing the solution at each time( of the form
%                x1(t1), x2(t1), x3(t1) ...
%                x1(t2), x2(t2), x3(t2) ...  
%                x1(t3), x2(t3), x3(t3) ...
%                 :         :        :
%                 
% t            = a vector containing the times which correspond to each element of x
%
% Description 
% -----------
% Uses a 4th order Runge-Kutta method to solve set of ode of the form dx/dt=f(x,t). The function f(x,t) is supplied by the 
% user and must be of the form
%
% function [dx/dt] = f(x,t)
% i.e. its input arguments are the solution at time t (a vector column vector [x1;x2;x3..]) and t. 
% It should return a vector of the form [dx1/dt;dx2/dt;dx3/dt...]
 
x(:,1) = InitialValues';
t(1) = Start;
 
%calculate the time ste
dt = (Finish-Start)/Nsteps;
 
for i = 1:Nsteps
       %calculate the four weighted trajectories k_i
       k1=feval(MyFunc,x(:,i),t(i))*dt;
       k2=feval(MyFunc,x(:,i)+k1/2,t(i)+dt/2)*dt;
       k3=feval(MyFunc,x(:,i)+k2/2,t(i)+dt/2)*dt;
       k4=feval(MyFunc,x(:,i)+k3,t(i)+dt)*dt;
       
       %calculate the new value of x and t, where x is a weighted average
       %of the trajectories calculated above
       t(i+1) = dt + t(i);
       x(:,i+1) = (k1+2*k2+2*k3+k4)/6 + x(:,i);
end

t = t';
x = x';
return